Type: Package
Package: amt
Title: Animal Movement Tools
Version: 0.3.1.0
Authors@R: c(
    person("Johannes", "Signer", , "jsigner@gwdg.de", role = c("aut", "cre")),
    person("Brian", "Smith", role = "ctb"),
    person("Bjoern", "Reineking", role = "ctb"),
    person("Ulrike", "Schlaegel", role = "ctb"),
    person("John", "Fieberg", role = "ctb"),
    person("Josh", "O'Brien", role = "ctb"),
    person("Bernardo", "Niebuhr", role = "ctb"),
    person("Alec", "Robitaille", role = "ctb"),
    person("Tal", "Avgar", role = "ctb"),
    person("Gerben", "IJntema", role = "ctb"),
    person("Scott", "LaPoint", role = "dtc")
  )
Description: Manage and analyze animal movement data. The functionality of
    'amt' includes methods to calculate home ranges, track statistics
    (e.g. step lengths, speed, or turning angles), prepare data for
    fitting habitat selection analyses, and simulation of space-use from
    fitted step-selection functions.
License: GPL-3
URL: https://github.com/jmsigner/amt
Depends: R (>= 4.1)
Imports: checkmate, circular, ctmm, data.table, dplyr (>= 0.7.0),
        fitdistrplus, FNN, graphics, grDevices, KernSmooth, lubridate,
        MASS, methods, purrr, Rdpack, rlang, sf, sfheaders, stats,
        survival, terra, tibble, tidyr (>= 1.0.0), utils
Suggests: adehabitatLT, broom, ggplot2, ggraph, geosphere, knitr,
        leaflet, moveHMM, rmarkdown, sessioninfo, suncalc, tidygraph,
        tinytest, units
VignetteBuilder: knitr
RdMacros: Rdpack
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-30 21:01:55 UTC; jsigner
Author: Johannes Signer [aut, cre],
  Brian Smith [ctb],
  Bjoern Reineking [ctb],
  Ulrike Schlaegel [ctb],
  John Fieberg [ctb],
  Josh O'Brien [ctb],
  Bernardo Niebuhr [ctb],
  Alec Robitaille [ctb],
  Tal Avgar [ctb],
  Gerben IJntema [ctb],
  Scott LaPoint [dtc]
Maintainer: Johannes Signer <jsigner@gwdg.de>
Repository: CRAN
Date/Publication: 2026-01-30 21:22:03 UTC
Built: R 4.6.0; ; 2026-04-26 16:06:33 UTC; unix
