# Generated by roxygen2: do not edit by hand

S3method("[",random_points)
S3method("[",steps_xy)
S3method("[",track_xy)
S3method("[",track_xyt)
S3method("[",uhc_data)
S3method(AIC,fit_clogit)
S3method(add_nsd,steps_xy)
S3method(add_nsd,track_xy)
S3method(arrange,random_points)
S3method(arrange,random_steps)
S3method(arrange,steps_xy)
S3method(arrange,track_xy)
S3method(arrange,track_xyt)
S3method(as.data.frame,uhc_data)
S3method(as_ltraj,track_xy)
S3method(as_ltraj,track_xyt)
S3method(as_moveHMM,track_xy)
S3method(as_sf,steps_xy)
S3method(as_sf,track_xy)
S3method(as_sf_lines,steps_xy)
S3method(as_sf_lines,track_xy)
S3method(as_sf_points,steps_xy)
S3method(as_sf_points,track_xy)
S3method(as_telemetry,track_xyt)
S3method(as_track,data.frame)
S3method(as_track,sfc_POINT)
S3method(as_track,steps_xyt)
S3method(bbox,steps_xy)
S3method(bbox,track_xy)
S3method(centroid,track_xy)
S3method(coef,fit_clogit)
S3method(coef,fit_logit)
S3method(coords,track_xy)
S3method(cum_dist,track_xy)
S3method(diff_x,track_xy)
S3method(diff_y,track_xy)
S3method(direction_abs,track_xy)
S3method(direction_rel,track_xy)
S3method(distinct,random_points)
S3method(extent_both,track_xy)
S3method(extent_max,track_xy)
S3method(extent_x,track_xy)
S3method(extent_y,track_xy)
S3method(extract_covariates,random_points)
S3method(extract_covariates,steps_xy)
S3method(extract_covariates,track_xy)
S3method(extract_covariates_along,steps_xy)
S3method(extract_covariates_var_time,steps_xyt)
S3method(extract_covariates_var_time,track_xyt)
S3method(filter,random_points)
S3method(filter,random_steps)
S3method(filter,steps_xy)
S3method(filter,track_xy)
S3method(filter,track_xyt)
S3method(filter_min_n_burst,track_xy)
S3method(flag_defunct_clusters,track_xyt)
S3method(flag_duplicates,track_xyt)
S3method(flag_fast_steps,track_xyt)
S3method(flag_roundtrips,track_xyt)
S3method(from,track_xyt)
S3method(from_to,track_xyt)
S3method(get_crs,default)
S3method(get_crs,hr)
S3method(get_crs,steps_xy)
S3method(get_crs,track_xy)
S3method(get_max_dist,fit_clogit)
S3method(group_by,random_points)
S3method(group_by,random_steps)
S3method(group_by,steps_xy)
S3method(group_by,track_xy)
S3method(group_by,track_xyt)
S3method(has_crs,default)
S3method(has_crs,hr)
S3method(has_crs,steps_xy)
S3method(has_crs,track_xy)
S3method(hr_akde,track_xyt)
S3method(hr_area,SpatRaster)
S3method(hr_area,akde)
S3method(hr_area,hr)
S3method(hr_cud,SpatRaster)
S3method(hr_cud,hr_prob)
S3method(hr_isopleths,PackedSpatRaster)
S3method(hr_isopleths,SpatRaster)
S3method(hr_isopleths,akde)
S3method(hr_isopleths,hr_prob)
S3method(hr_isopleths,locoh)
S3method(hr_isopleths,mcp)
S3method(hr_kde,track_xy)
S3method(hr_kde_pi,track_xy)
S3method(hr_kde_ref,track_xy)
S3method(hr_locoh,track_xy)
S3method(hr_mcp,track_xy)
S3method(hr_od,track_xyt)
S3method(hr_overlap,hr)
S3method(hr_overlap,list)
S3method(hr_to_sf,list)
S3method(hr_to_sf,tbl_df)
S3method(hr_ud,hr_prob)
S3method(inspect,track_xy)
S3method(intensity_use,track_xy)
S3method(log_rss,fit_clogit)
S3method(log_rss,glm)
S3method(make_start,numeric)
S3method(make_start,steps_xyt)
S3method(make_start,track_xyt)
S3method(make_trast,track_xy)
S3method(msd,track_xy)
S3method(mutate,steps_xy)
S3method(mutate,track_xy)
S3method(mutate,track_xyt)
S3method(nest,random_points)
S3method(nest,random_steps)
S3method(nest,steps_xy)
S3method(nest,track_xy)
S3method(nsd,track_xy)
S3method(od,track_xyt)
S3method(plot,hr)
S3method(plot,log_rss)
S3method(plot,random_points)
S3method(plot,random_steps)
S3method(plot,track_xy)
S3method(plot,uhc_data)
S3method(plot,uhc_envelopes)
S3method(plot_sl,fit_clogit)
S3method(plot_sl,random_steps)
S3method(points,track_xy)
S3method(prep_uhc,fit_clogit)
S3method(prep_uhc,fit_logit)
S3method(prep_uhc,glm)
S3method(random_numbers,amt_distr)
S3method(random_numbers,hnorm_distr)
S3method(random_numbers,vonmises_distr)
S3method(random_points,default)
S3method(random_points,hr)
S3method(random_points,sf)
S3method(random_points,track_xy)
S3method(random_steps,bursted_steps_xyt)
S3method(random_steps,numeric)
S3method(random_steps,steps_xy)
S3method(range_both,track_xy)
S3method(range_x,track_xy)
S3method(range_y,track_xy)
S3method(remove_capture_effect,track_xyt)
S3method(remove_incomplete_strata,random_steps)
S3method(rolling_od,track_xyt)
S3method(sdr,track_xyt)
S3method(select,random_points)
S3method(select,random_steps)
S3method(select,steps_xy)
S3method(select,track_xy)
S3method(select,track_xyt)
S3method(simulate_path,default)
S3method(simulate_path,redistribution_kernel)
S3method(sinuosity,track_xy)
S3method(site_fidelity,steps_xy)
S3method(sl_distr,fit_clogit)
S3method(sl_distr,random_steps)
S3method(sl_distr_name,fit_clogit)
S3method(sl_distr_name,random_steps)
S3method(sl_distr_params,fit_clogit)
S3method(sl_distr_params,random_steps)
S3method(speed,track_xyt)
S3method(step_lengths,track_xy)
S3method(steps,track_xy)
S3method(steps,track_xyt)
S3method(steps_by_burst,track_xyt)
S3method(straightness,track_xy)
S3method(summarise,random_points)
S3method(summarise,random_steps)
S3method(summarise,steps_xy)
S3method(summarise,track_xy)
S3method(summarise,track_xyt)
S3method(summarize,random_points)
S3method(summarize,random_steps)
S3method(summarize,steps_xy)
S3method(summarize,track_xy)
S3method(summarize,track_xyt)
S3method(summarize_sampling_rate,track_xyt)
S3method(summarize_sampling_rate_many,track_xyt)
S3method(summary,fit_clogit)
S3method(summary,fit_logit)
S3method(ta_distr,fit_clogit)
S3method(ta_distr,random_steps)
S3method(ta_distr_name,fit_clogit)
S3method(ta_distr_name,random_steps)
S3method(ta_distr_params,fit_clogit)
S3method(ta_distr_params,random_steps)
S3method(tac,track_xy)
S3method(time_of_day,steps_xyt)
S3method(time_of_day,track_xyt)
S3method(to,track_xyt)
S3method(tot_dist,track_xy)
S3method(track_align,track_xyt)
S3method(track_resample,track_xyt)
S3method(transform_coords,track_xy)
S3method(ungroup,track_xy)
S3method(ungroup,track_xyt)
S3method(unnest,nested_track)
export(NA_crs_)
export(Surv)
export(add_nsd)
export(arrange)
export(as_degree)
export(as_ltraj)
export(as_moveHMM)
export(as_rad)
export(as_sf)
export(as_sf_lines)
export(as_sf_points)
export(as_sp)
export(as_telemetry)
export(as_track)
export(available_distr)
export(bbox)
export(calculate_sdr)
export(centroid)
export(clogit)
export(conf_envelope)
export(coords)
export(cum_dist)
export(days)
export(diff_x)
export(diff_y)
export(direction_abs)
export(direction_rel)
export(distinct)
export(extent_both)
export(extent_max)
export(extent_x)
export(extent_y)
export(extract_covariates)
export(extract_covariates_along)
export(extract_covariates_var_time)
export(filter)
export(filter_min_n_burst)
export(fit_clogit)
export(fit_ctmm)
export(fit_distr)
export(fit_issf)
export(fit_logit)
export(fit_rsf)
export(fit_ssf)
export(flag_defunct_clusters)
export(flag_duplicates)
export(flag_fast_steps)
export(flag_roundtrips)
export(from)
export(from_to)
export(get_amt_fisher_covars)
export(get_crs)
export(get_displacement)
export(get_max_dist)
export(get_sh_forest)
export(group_by)
export(has_crs)
export(hours)
export(hr_akde)
export(hr_area)
export(hr_cud)
export(hr_isopleths)
export(hr_kde)
export(hr_kde_lscv)
export(hr_kde_pi)
export(hr_kde_ref)
export(hr_kde_ref_scaled)
export(hr_locoh)
export(hr_mcp)
export(hr_od)
export(hr_overlap)
export(hr_overlap_feature)
export(hr_to_sf)
export(hr_ud)
export(inspect)
export(intensity_use)
export(log_rss)
export(make_distribution)
export(make_exp_distr)
export(make_gamma_distr)
export(make_hnorm_distr)
export(make_issf_model)
export(make_lnorm_distr)
export(make_start)
export(make_track)
export(make_trast)
export(make_unif_distr)
export(make_vonmises_distr)
export(map)
export(map_int)
export(minutes)
export(mk_track)
export(msd)
export(mutate)
export(nest)
export(nsd)
export(od)
export(plot_sl)
export(prep_uhc)
export(pull)
export(random_numbers)
export(random_points)
export(random_steps)
export(random_steps_simple)
export(range_both)
export(range_x)
export(range_y)
export(redistribution_kernel)
export(remove_capture_effect)
export(remove_incomplete_strata)
export(rolling_od)
export(sampling_period)
export(sdr)
export(seconds)
export(select)
export(simulate_path)
export(sinuosity)
export(site_fidelity)
export(sl_distr)
export(sl_distr_name)
export(sl_distr_params)
export(speed)
export(ssf_formula)
export(step_lengths)
export(steps)
export(steps_by_burst)
export(straightness)
export(strata)
export(summarise)
export(summarize)
export(summarize_sampling_rate)
export(summarize_sampling_rate_many)
export(summarize_sl)
export(summarize_speed)
export(ta_distr)
export(ta_distr_name)
export(ta_distr_params)
export(tac)
export(tibble)
export(time_of_day)
export(to)
export(tot_dist)
export(track)
export(track_align)
export(track_resample)
export(tracked_from_to)
export(transform_coords)
export(ungroup)
export(unnest)
export(update_exp)
export(update_gamma)
export(update_hnorm)
export(update_lnorm)
export(update_sl_distr)
export(update_ta_distr)
export(update_vonmises)
export(weeks)
import(Rdpack)
import(survival)
importFrom(dplyr,arrange)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(grDevices,adjustcolor)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(lubridate,"%within%")
importFrom(lubridate,days)
importFrom(lubridate,hours)
importFrom(lubridate,minutes)
importFrom(lubridate,now)
importFrom(lubridate,seconds)
importFrom(lubridate,weeks)
importFrom(methods,as)
importFrom(methods,is)
importFrom(purrr,map)
importFrom(purrr,map_int)
importFrom(rlang,enquo)
importFrom(rlang,quo)
importFrom(rlang,quo_name)
importFrom(rlang,quos)
importFrom(sf,NA_crs_)
importFrom(stats,coef)
importFrom(stats,dexp)
importFrom(stats,dgamma)
importFrom(stats,formula)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,qexp)
importFrom(stats,qgamma)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reformulate)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(survival,clogit)
importFrom(survival,strata)
importFrom(tibble,as_tibble)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tibble,tribble)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,tail)
